Coverage report

# Coverage report: 28%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 5549 | 4000 | 19 | 28%
airflow.py | 43 | 15 | 0 | 65%
airflow/bin.py | 0 | 0 | 0 | 100%
airflow/bin/cli.py | 371 | 306 | 0 | 18%
airflow/configuration.py | 197 | 77 | 0 | 61%
airflow/exceptions.py | 8 | 0 | 0 | 100%
airflow/executors.py | 27 | 13 | 0 | 52%
airflow/executors/base_executor.py | 53 | 33 | 9 | 38%
airflow/executors/celery_executor.py | 60 | 33 | 0 | 45%
airflow/executors/local_executor.py | 49 | 32 | 0 | 35%
airflow/executors/sequential_executor.py | 22 | 11 | 0 | 50%
airflow/hooks/S3_hook.py | 179 | 143 | 10 | 20%
airflow/hooks.py | 16 | 8 | 0 | 50%
airflow/hooks/base_hook.py | 43 | 22 | 0 | 49%
airflow/hooks/dbapi_hook.py | 117 | 92 | 0 | 21%
airflow/hooks/hive_hooks.py | 290 | 251 | 0 | 13%
airflow/hooks/http_hook.py | 44 | 34 | 0 | 23%
airflow/hooks/mysql_hook.py | 38 | 29 | 0 | 24%
airflow/hooks/postgres_hook.py | 19 | 10 | 0 | 47%
airflow/hooks/sqlite_hook.py | 10 | 3 | 0 | 70%
airflow/jobs.py | 609 | 530 | 0 | 13%
airflow/macros.py | 25 | 12 | 0 | 52%
airflow/macros/hive.py | 31 | 27 | 0 | 13%
airflow/models.py | 1738 | 1298 | 0 | 25%
airflow/operators.py | 17 | 8 | 0 | 53%
airflow/operators/bash_operator.py | 46 | 30 | 0 | 35%
airflow/operators/check_operator.py | 125 | 91 | 0 | 27%
airflow/operators/dagrun_operator.py | 28 | 15 | 0 | 46%
airflow/operators/docker_operator.py | 73 | 57 | 0 | 22%
airflow/operators/dummy_operator.py | 9 | 2 | 0 | 78%
airflow/operators/hive_operator.py | 37 | 20 | 0 | 46%
airflow/operators/http_operator.py | 26 | 14 | 0 | 46%
airflow/operators/mysql_operator.py | 19 | 8 | 0 | 58%
airflow/operators/postgres_operator.py | 19 | 8 | 0 | 58%
airflow/operators/python_operator.py | 63 | 45 | 0 | 29%
airflow/operators/sensors.py | 228 | 155 | 0 | 32%
airflow/operators/subdag_operator.py | 29 | 16 | 0 | 45%
airflow/plugins_manager.py | 79 | 39 | 0 | 51%
airflow/security.py | 0 | 0 | 0 | 100%
airflow/security/utils.py | 37 | 27 | 0 | 27%
airflow/settings.py | 53 | 11 | 0 | 79%
airflow/utils.py | 6 | 2 | 0 | 67%
airflow/utils/asciiart.py | 2 | 0 | 0 | 100%
airflow/utils/dates.py | 62 | 51 | 0 | 18%
airflow/utils/db.py | 110 | 82 | 0 | 25%
airflow/utils/decorators.py | 48 | 34 | 0 | 29%
airflow/utils/email.py | 56 | 38 | 0 | 32%
airflow/utils/file.py | 16 | 8 | 0 | 50%
airflow/utils/helpers.py | 122 | 95 | 0 | 22%
airflow/utils/logging.py | 90 | 71 | 0 | 21%
airflow/utils/operator_helpers.py | 15 | 14 | 0 | 7%
airflow/utils/state.py | 30 | 10 | 0 | 67%
airflow/utils/timeout.py | 28 | 15 | 0 | 46%
airflow/utils/trigger_rule.py | 13 | 2 | 0 | 85%
airflow/www.py | 0 | 0 | 0 | 100%
airflow/www/app.py | 66 | 50 | 0 | 24%
airflow/www/blueprints.py | 8 | 3 | 0 | 63%

No items found using the specified filter.